@@ -5,7 +5,7 @@ use typenum;
 
 fn main() {
     let height = unit!("ft.").pq(5f64) + unit!("in.").pq(8f64);
-    let cm = unit!("cm").value(height).unwrap();
+    let cm = unit!("cm").value(height);
 
     assert_eq!(cm, 172.72);
 }
\ No newline at end of file
