@@ -1,8 +1,7 @@
 #![doc = include_str!("../README.md")]
 use proc_macro::TokenStream;
-use syn::parse_macro_input;
+use syn:: { ExprPath, parse_macro_input };
 use quote::quote;
-use const_frac::frac::syn::ClonedPath;
 
 mod unit;
 
@@ -17,7 +16,7 @@ pub fn unit(input: TokenStream) -> TokenStream {
 
 #[proc_macro]
 pub fn dim(input: TokenStream) -> TokenStream {
-    let result = parse_macro_input!(input as TokenDim<ClonedPath>);
+    let result = parse_macro_input!(input as TokenDim<ExprPath>);
 
     quote! { #result }.into()
 }
\ No newline at end of file
